import { Image, Video, VideoProps } from "@tarojs/components";
import { ECharacterAISTATUS } from "@/types/index";
import { useCharacterAIStore } from "@/store/characterAIStore";
import style from "../index.module.less";
import { ICharacter } from "@/types";
import { useEffect, useRef } from "react";
import Taro from "@tarojs/taro";

interface Props {
  character: ICharacter;
}

export const AvatarMedia = ({ character }: Props) => {
  const AIStatus = useCharacterAIStore((state) => state.status);
  const videoRef = useRef<React.ComponentType<VideoProps>|null>(null);
  const videoContext = useRef<Taro.VideoContext|null>(null);
  const videoId = useRef(`video-${Math.random().toString(36).substr(2, 9)}`);

  const videoErrorCallback = (e) =>  {
    console.log('Video error info:')
    console.log(e.detail)
 }

 // 处理 ios 上无法循环播放的 bug
 const handleOnEnded = () => {
  if(AIStatus === ECharacterAISTATUS.RESPONDING && videoContext.current){
    videoContext.current.seek(0)
    videoContext.current.play()
  }
 }


  useEffect(() => {
    if (videoRef.current) {
      videoContext.current = Taro.createVideoContext(videoId.current, this);
    }
  }, []);

  useEffect(() => {
    if (videoContext.current) {
      if (AIStatus === ECharacterAISTATUS.RESPONDING) {
        videoContext.current.play();
      } else {
        videoContext.current.seek(0)
        videoContext.current.pause();
        console.log('video play end')
      }
    }
  }, [AIStatus]);

  if (!character?.avatar) {
    return <></>;
  }

  if (character.avatar?.lastIndexOf('.mp4') > -1) {
    return (
      <Video
        id={videoId.current}
        ref={videoRef}
        controls={false}
        showCenterPlayBtn={false}
        loop={true}
        muted={true}
        onEnded={handleOnEnded}
        objectFit="cover"
        className={`${style.avatar}`}
        onError={videoErrorCallback}
        // src="https://cdn.wehome.cn/cmn/mp4/3/META-H8UKWHWU-YAUTZH7ECGRDC57FD3NI3-CUGVCS8M-CD.mp4"
        src={character.avatar}
      />
    );  
  }

  return (
    <Image
      mode="aspectFill"
      className={style.avatar}
      src={character.avatar}
    />
  );
};
