import { useRef,useEffect } from "react";
import { useLongPress } from "use-long-press";
import style from '../../index.module.less';
interface Props {
  speechStatus: number,
  onLongPress: () => void,
  onTouchEnd: () => void,
}
export default ({speechStatus, onLongPress, onTouchEnd}:Props) => {
  // 适配 h5
  const recordRef = useRef<HTMLDivElement | null>(null);
  useEffect(() => {
    console.log("[ 首次挂载 ] >");
    const handleTouchStart = (e: TouchEvent) => {
      console.log("touchstart", e);
      e.preventDefault();
      e.stopPropagation();
    };
    recordRef.current?.addEventListener("click", handleTouchStart);
    recordRef.current?.addEventListener("touchstart", handleTouchStart);
    return () => {
      recordRef.current?.removeEventListener("touchstart", handleTouchStart);
      recordRef.current?.removeEventListener("click", handleTouchStart);
    };
  }, []);
  const bind = useLongPress(
    () => {
      console.log("[ longpress ] >");
      onLongPress();
    },
    {
      onStart: (e) => {
        e.stopPropagation();
        e.preventDefault();
        console.log("start");
      },
      onCancel: () => {
        console.log("cancel");
      },
      onFinish: () => {
        console.log("finish");
        onTouchEnd();
      },
      threshold: 150,
    }
  );
  const render = () =>{
    if (speechStatus === 0) {
      return (
        <div className={style.speechButton} {...bind()} ref={recordRef}>
          <div
            className={`iconfont icon-a-icon_24_micon ${style.iconMic}`}
          ></div>
          <div>按住对话</div>
        </div>
      );
    }
    if (speechStatus === 1) {
      return (
        <div className={style.speechButtonActive}>
          <img
            src='https://cdn.wehome.cn/cmn/gif/199/META-H8UKVHWU-KIGP3BIL7M5AYC6XHNUA2-OSAK6A2M-72.gif'
            style={{
              objectFit: "contain",

              height: "80%",
            }}
          ></img>
        </div>
      );
    }
  }
  return <>
    {render()}
  </>
}