import { View, Image, Text } from "@tarojs/components";
import style from './index.module.less'
import IconCopy from "@/components/icon/icon-copy";
import IconSpeaker from "@/components/icon/icon-speaker";
import { ICharacter } from "@/types";
import Taro from "@tarojs/taro";
import ThinkAnimation from '../think-animation/index'
interface Props {
  character: ICharacter,
  text: string,
  textReasoning: string,
}
export default ({character, text, textReasoning=''}:Props) => {
  const handleCopy = (e: any)=> {
    e.stopPropagation();
    // 手动复制并 toast 提示
    if(text){
      Taro.setClipboardData({
        data: text,
        success(){
          Taro.showToast({
            title: '复制成功',
            icon: 'none'
          })
        },fail(res) {
          console.log(res)
          Taro.showToast({
            title: '复制失败',
            icon: 'none'
          })
        },
      })
    }
  }
  return <View>
      <View className="flex gap-8 mb-10">
        <View className={style.avatarContainer}>
          {character?.avatar && (
            <Image
              mode="aspectFill"
              className={style.avatar}
              src={character.avatar}
            />
          )}
        </View>
        <View className="font-medium text-16 leading-24">{character?.name}</View>
      </View>

      <View className={`${style.message } ${style.messageRobot} gap-10`}>
        <View className={style.messageContent}>
        {textReasoning && <View className={style.deepThinkContainer}>
            <View className="font-bold">深度思考：</View>
            <Text>
              {textReasoning}
            </Text>
          </View>}

        {text.length === 0 && <ThinkAnimation></ThinkAnimation>}
          <Text>{text}</Text>
        </View>
        <View className="flex gap-8">
          <View onClick={handleCopy}><IconCopy></IconCopy></View>
          {/* <IconSpeaker></IconSpeaker> */}
        </View>
    </View>
  </View>
}


