import Taro from "@tarojs/taro";
import { View, Image } from "@tarojs/components";
import WidgetCard from "@/components/widgets/widget-card/index";
import style from "./index.module.less";
import type {
  IEntityDocument,
  TEntityComponent,
} from "@/types/index";

interface Props {
  index: number;
  editMode: boolean;
  component: TEntityComponent;
  components: TEntityComponent[];
  onSwitchChanged: (c: TEntityComponent, checked: boolean) => void;
  onDelete: (c: IEntityDocument) => void;
  onMove: (c: TEntityComponent, direction: number) => void;
  onClick: (c:TEntityComponent, url: string ) => void;
}

const redirectTips = ()=> {
  return (
    <View className="text-white text-10 leading-18 bg-gray-45 rounded-30 right-8 bottom-8 inline-block absolute px-6">跳转视频号查看</View>
  )
}

export default ({
  index,
  editMode,
  component,
  components,
  onSwitchChanged,
  onDelete,
  onMove,
  onClick,
}: Props) => {
  
  const openShipingVideo = (value:any)=> {
    if(!value.videoId || !value.accountId){
      return
    }
    Taro.openChannelsActivity({
      finderUserName: value.accountId,
      feedId: value.videoId,
      success: (res) => {
        console.log(res);
      },
      fail: (err) => {
        console.log(err);
      }
    })
  }
  const handleClick = ()=> {
    if(editMode){
      onClick(component, `/pages/editor-pages/editor-channels/index`)
    }else{
      openShipingVideo(component.data?.value)
    }
  }

  if(!editMode){
    return <View className="rounded-20 overflow-hidden bg-white" onClick={handleClick}>
      <View className="px-16 py-18" >
          <View className="flex items-center gap-8">
            <View className={style.iconVideo}></View>
            <View className="text-16 font-medium">{component.data?.value?.desc ?? '视频名称'}</View>  
          </View>
            
          </View>
          {component.data?.value?.poster && 
              <View className="w-full overflow-hidden relative">
                <Image
                  className="w-full align-bottom"
                  mode="widthFix"
                  src={component.data.value.poster}
                ></Image>
                {redirectTips()}
              </View>
            }
    </View>
  }

  return (
    <>
      <WidgetCard
        disableChangeStyle
        index={index}
        enabled={component.enabled}
        onSwitchChanged={(checked)=> onSwitchChanged(component, checked)}
        components={components}
        editMode={editMode}
        onDelete={() => onDelete(component)}
        onMove={(direction) => onMove(component, direction)}
        onClick={handleClick}
      >
        <View className="px-16">
          <View className="flex items-center gap-8">
            <View className={style.iconVideo}></View>
            <View className="text-16 font-medium">{component.data?.value?.desc ?? '视频名称'}</View>  
          </View>
            {component.data?.value?.poster && 
              <View className="w-full overflow-hidden mt-16 relative">
                <Image
                  className="w-full align-bottom"
                  mode="widthFix"
                  src={component.data.value.poster}
                  lazyLoad
                ></Image>
                {redirectTips()}
              </View>
            }
          </View>
          
      </WidgetCard>
    </>
  );
};
