import Taro from "@tarojs/taro";
import { View, Image } from "@tarojs/components";
import WidgetCard from "@/components/widgets/widget-card/index";
import WidgetMedia from "@/components/widgets/widget-media/index";
import style from "./index.module.less";
import IconArrowRight from "@/images/icon_24_right.png";
import type {
  IEntityDocument,
  TEntityComponent,
} from "@/types/index";

interface Props {
  index: number;
  editMode: boolean;
  component: TEntityComponent;
  components: TEntityComponent[];
  onSwitchChanged: (c: TEntityComponent, checked: boolean) => void;
  onDelete: (c: IEntityDocument) => void;
  onMove: (c: TEntityComponent, direction: number) => void;
  onClick: () => void;
  onStyleChanged: (c: TEntityComponent) => void
}

export default ({
  index,
  editMode,
  component,
  components,
  onSwitchChanged,
  onDelete,
  onMove,
  onClick,
  onStyleChanged,
}: Props) => {
    
  // 非编辑模式下样式需要特殊处理，与其它组件不同
  if(!editMode){
    return (
      <>
        <WidgetMedia
          layout={component.data?.layout}
          mediaList={component.data?.media}
        ></WidgetMedia>
      </>
    )
  }
  
  return (
    <>
      <WidgetCard
        key={component.id}
        enabled={component.enabled}
        onSwitchChanged={(checked) => onSwitchChanged(component, checked)}
        index={index}
        components={components}
        editMode={editMode}
        onDelete={() => onDelete(component)}
        onMove={(direction) =>  onMove(component, direction)}
        onClick={onClick}
        onChanged={()=> {
          if(component.data?.layout === 'mini'){
            onStyleChanged({...component, data: {...component.data, layout: 'full'}})
          }else{
            onStyleChanged({...component, data: {...component.data, layout: 'mini'}})
          }
        }}
      >
        <WidgetMedia
          editMode={editMode}
          layout={component.data?.layout}
          mediaList={component.data?.media}
        ></WidgetMedia>
      </WidgetCard>
    </>
  );
};
