import {View} from '@tarojs/components'
import WidgetCard from "@/components/widgets/widget-card/index";
import WidgetTypeRow, {
} from "@/components/widgets/widget-type-row/index";
import type {
  IEntityDocument,
  TEntityComponent,
} from "@/types/index";
import Taro from '@tarojs/taro';
import IconPhone from '@/components/icon/icon-phone'

interface Props {
  index: number
  editMode: boolean
  component: TEntityComponent
  components: TEntityComponent[]
  onSwitchChanged: (c: TEntityComponent, checked: boolean)=> void
  onDelete:(c: IEntityDocument)=> void
  onMove: (c: TEntityComponent, direction: number) => void
  onStyleChanged: (c: TEntityComponent) => void
  onClick: () => void;
}
export default ({
  index,
  editMode,
  component,
  components,
  onSwitchChanged,
  onDelete,
  onMove,
  onStyleChanged,
  onClick
}:Props) => {
  const handleClick = ()=> {
    if(editMode){
      onClick()
    }else{
      Taro.makePhoneCall({phoneNumber: component?.data?.text})
    }
  }
  return <>
    
      <WidgetCard
        enabled={component.enabled}
        onSwitchChanged={(checked)=> onSwitchChanged(component, checked)}
        index={index}
        components={components}
        editMode={editMode}
        onDelete={() => onDelete(component)}
        onMove={(direction) => onMove(component, direction)}
        onChanged={()=> {
          if(component.data?.layout === 'left'){
            onStyleChanged({...component, data: {...component.data, layout: 'center'}})
          }else{
            onStyleChanged({...component, data: {...component.data, layout: 'left'}})
          }
        }}
      >
        <WidgetTypeRow
          editMode={editMode}
          onClick={handleClick}
          layout={component?.data?.layout}
          type={IconPhone()}
        >
          {component?.data?.text}
        </WidgetTypeRow>
      </WidgetCard>
  </>
}