import { Canvas } from "@tarojs/components";
import style from './index.module.less'
import { getSharePromise, getCanvasTempPath } from "@/utils/index";
// import { useCurrentCharacter } from "@/store/characterStore";
import {
  Application,
  ImgLoader,
  Container,
  Image as DuduImage,
  RichText,
} from "../../libs/duducanvas/index";
import Taro, { useShareAppMessage, useShareTimeline } from "@tarojs/taro";
import { ICharacter } from "@/types";
import { getAvatarImageSrc } from "./shareUtils";
import Stage from "@/libs/duducanvas/Stage";

const getCanvasSize = () => {
  // 根据屏幕宽度计算 canvas 宽度
  const systemInfo = Taro.getWindowInfo();
  const screenWidth = systemInfo.windowWidth;
  const designWidth = 375;
  const designHeight = 300;
  // 宽高放大一倍
  const canvasWidth = screenWidth * 2;
  const canvasHeight = (screenWidth / designWidth) * designHeight * 2;
  const ratio = canvasWidth / 210;
  return {
    canvasWidth,
    canvasHeight,
    ratio,
  };
};

const drawCircleEffect = (avatar: Container, ratio: number)=> {
  const circle0 = new Container();
  circle0.width = 178 * ratio;
  circle0.height = 178 * ratio;
  circle0.borderRadius = "100%";
  circle0.shadow = "0 0 20px rgba(0,0,0,.02)";
  circle0.backgroundColor = "#f6f6f6";

  const circle1 = new Container();
  circle1.x = 0;
  circle1.y = 0;
  circle1.width = 138 * ratio;
  circle1.height = 138 * ratio;
  circle1.borderRadius = "100%";
  circle1.shadow = "0 0 20px rgba(0,0,0,.02)";
  circle1.backgroundColor = "#f8f8f8";

  const circle2 = new Container();
  circle2.x = 0;
  circle2.y = 0;
  circle2.width = 102 * ratio;
  circle2.height = 102 * ratio;
  circle2.borderRadius = "100%";
  circle2.shadow = "0 0 20px rgba(0,0,0,.02)";
  circle2.backgroundColor = "#fafafa";

  circle2.addChild(avatar);
  circle1.addChild(circle2);
  circle0.addChild(circle1);
  return circle0
}

interface Props {
  character: ICharacter;
}

export default (props: Props) => {
  const { canvasWidth, canvasHeight, ratio } = getCanvasSize();
  let stage: Stage|null;

  // character = useCurrentCharacter
  const character = props.character
  const initCanvas = async () => {
    // console.log('share:', character)
    if(!character){
      return 
    }
    const app = new Application(
      "#myShareCanvas",
      { width: canvasWidth, height: canvasHeight },
      null
    );
    stage = await app.init();
    if(!stage){
      return;
    }
    
    let avatarImg = getAvatarImageSrc(character.avatar ?? "")
    
    const card = new Container();
    const imgArr = [
      {
        id: "avatar",
        src: avatarImg,
      }
    ]
    // if(character.bgImg){
    //   imgArr.push({
    //     id: 'bgImg',
    //     src: character.bgImg
    //   })
    // }
    const loader = new ImgLoader(stage.canvas, imgArr);
    await loader.load();  
    
    // 如果有设置过背景，则绘制背景
    // const bgImgTexture = loader.get("bgImg");
    // if (bgImgTexture) {
    //   const bgImg = new DuduImage({
    //     image: bgImgTexture.image,
    //     dWidth: canvasWidth,
    //     height: canvasWidth / bgImgTexture.width * bgImgTexture.height,
    //   });
    //   stage.addChild(bgImg);
    // }

    card.x = 0;
    card.y = -140;
    card.gap = 5;
    card.width = 210 * ratio;
    card.height = 200 * ratio;
    

    // 矩形用于头像，及头像背景效果
    const rect = new Container();
    rect.y = -140 * ratio;
    rect.direction = "column";
    rect.justifyContent = "space-around";
    rect.width = 210 * ratio;
    rect.height = 200 * ratio;
    rect.borderRadius = 0;
    card.addChild(rect);

    

    // 头像
    const avatarTexture = loader.get("avatar");
    
    if (avatarTexture) {
      const dWidth = 80;
      const avatar = new DuduImage({
        image: avatarTexture.image,
        dWidth: (dWidth) * ratio,
        dHeight: (avatarTexture.height * dWidth/avatarTexture.width) * ratio,
      });
      const avatarWrapper = new Container()
      avatarWrapper.width = dWidth * ratio
      avatarWrapper.height = dWidth * ratio
      avatarWrapper.overflowHidden = true
      avatarWrapper.borderRadius = '100%'
      avatarWrapper.addChild(avatar)
      
      const circleBg = drawCircleEffect(avatarWrapper, ratio)
      card.backgroundColor = "white";
      rect.backgroundColor = "#f5f5f5";
      rect.addChild(circleBg)
      // // 如果没有背景则绘制圆形头像圆圈背景效果
      // if(!character.bgImg?.length){
      //   const circleBg = drawCircleEffect(avatar, ratio)
      //   card.backgroundColor = "white";
      //   rect.backgroundColor = "#f5f5f5";
      //   rect.addChild(circleBg)
      // }else{
      //   // 如果有背景，则不绘制头像的圆圈背景效果
      //   rect.addChild(avatar)
      // }
    }

    // 名称与公司名容器
    const infoList = new Container();
    infoList.y = 110 * ratio;
    infoList.direction = "column";
    infoList.gap = 4 * ratio;
    infoList.width = 216 * ratio;
    infoList.height = 42 * ratio;

    // 用户名
    const name = new RichText({
      text: character?.name ?? '',
      fontSize: 15 * ratio,
      color: "black",
      fontWeight: 500,
    });
    name.wrapWidth = 180 * ratio;
    name.lineClamp = 1;
    name.shadow = '0 0 4 white'
    name.height = 22 * ratio;

    // 单位名
    const companyName = new RichText();
    companyName.x = 0;
    companyName.y = 0;
    companyName.lineClamp = 1;
    companyName.text = character?.company ?? '';
    companyName.wrapWidth = 160 * ratio;
    companyName.fontSize = 12 * ratio;
    companyName.color = "rgba(0, 0, 0, .45)";
    companyName.letterSpace = 4;
    companyName.lineGap = 8;
    companyName.shadow = '0 0 4 white'
    infoList.addChild(name, companyName);

    stage.addChild(card, infoList);
    stage.update();
  };

  // 延迟获取 canvas
  
  // Taro.nextTick(() => {
  //   initCanvas();
  // });

  const shareTitle = 'AI智能主页' // '想了解我？快和我的AI聊聊吧',
  useShareAppMessage(async () => {
    const profileId = character?.profileId;
    Taro.showLoading()
    await initCanvas();
    let tmpImage = ''
    if(stage){
      tmpImage = await getCanvasTempPath(stage.canvas, "myShareCanvas");
    }
    
    const sharePromise = await getSharePromise(profileId);
    Taro.hideLoading()
    const o = {
      title: shareTitle,
      path: sharePromise.path ?? "/pages/index/index",
      imageUrl: tmpImage,
      promise: sharePromise,
    };
    return o;
  });

  useShareTimeline(() => {
    const profileId = character?.profileId;
    const o = {
      title: shareTitle,
      query: `profileId=${profileId}`,
    };
    return o;
  });

  return (
    <Canvas
      type="2d"
      id="myShareCanvas"
      width={String(canvasWidth)}
      height={String(canvasHeight)}
      style={`width: ${canvasWidth / 2}px; height: ${canvasHeight / 2}px;`}
      className={style.canvas}
    />
  );
};
