import { useMemo, useRef } from "react";
import { View, Image, Button, RootPortal } from "@tarojs/components";
import Taro from "@tarojs/taro"
import style from "./index.module.less";
import IconShareWechat from "@/images/icon-share-wechat.png";
import IconShareQrcode from "@/images/icon-share-qrcode.png";
import IconShareLink from "@/images/icon-share-link.png";
import { ICharacter } from "@/types/index";
import ShareCard, {type IShareCard} from "@/components/custom-share/share-card/index";
import CustomShareComponent from "@/components/custom-share/CustomShareComponent";
import { HOME_URL } from '@/config'
import { useCurrentCharacter } from "@/store/characterStore";
import Popup from "@/components/popup/popup";


interface Props {
  show: boolean;
  character: ICharacter | null;
  setShow: (show:boolean) => void;
}
export default ({ show, setShow, character }: Props) => {
  const currentCharacter = useCurrentCharacter();
  const shareCardRef = useRef<IShareCard>(null)
  // todo: 优化至点击后再去生成小程序二维码
  const ShareCardComponent = useMemo(
    () => {
      if(character){
        return <ShareCard ref={shareCardRef} character={character}></ShareCard>
      }
    }, [character]
  );
  

  const handleSavePicture = () => {
    console.log(shareCardRef?.current)
    shareCardRef?.current?.saveCardToAlbum(); // 调用子组件的保存方法
  }

  const handleCopyLink = () => {
    Taro.setClipboardData({
      data: `${HOME_URL}${character?.profileId}`,
      success(){
        Taro.showToast({
          title: '复制成功',
          icon: 'none'
        })
      },fail(res) {
        console.log(res)
        Taro.showToast({
          title: '复制失败',
          icon: 'none'
        })
      },
    })
  }
  // 默认要生成分享图
  const renderSharePicture = ()=> {
    if(currentCharacter?.profileId === character?.profileId){
      return <CustomShareComponent character={character} />
    }
    return <></>
  }

  // if (!visible) {
  //   return <></>;
  // }
  

  return (
    <RootPortal>
      { renderSharePicture() }
      <Popup show={show} setShow={setShow}>
        {/* 显示分享弹窗后再进行分享逻辑 */}
        <View className={style.container}>
          <View className={style.optionButtons}>
              <View className={style.optionButton}>
                <Image src={IconShareWechat} className={style.icon}></Image>
                <View className={style.buttonText}>微信好友</View>
                <Button openType="share" className="share-button"></Button>
              </View>
              <View className={style.optionButton} onClick={handleSavePicture}>
                <Image src={IconShareQrcode} className={style.icon}></Image>
                <View className={style.buttonText}>保存图片</View>
              </View>
              <View className={style.optionButton} onClick={handleCopyLink}>
                <Image src={IconShareLink} className={style.icon}></Image>
                <View className={style.buttonText}>复制链接</View>
              </View>
            </View>
          
          {ShareCardComponent}
        </View>
      </Popup> 
    </RootPortal>
  );
};
