import { View, Image } from "@tarojs/components";
import style from "./index.module.less";
import IconArrowThin from "@/components/icon/icon-arrow-thin";


interface Props {
  arrow?: boolean;
  children?: JSX.Element[] | JSX.Element;
  leftRenderer?: ()=> JSX.Element[] | JSX.Element; 
  rightRenderer?: () => JSX.Element[] | JSX.Element;
  className?: string,
  onClick?: () => void;
  underline?: boolean;
}
export default ({
  arrow = false,
  underline = false,
  className = '',
  leftRenderer,
  rightRenderer,
  onClick,
  children,
}: Props) => {
  const handleClick = () => {
    onClick && onClick();
  };
  return (
    <View
      className={`flex w-full bg-white gap-12 ${className}`}
      onClick={handleClick}
    >
      {leftRenderer && <View className="flex items-center justify-center">{leftRenderer()}</View>}
      <View className={`${
        underline ? style.underline : ""
      } flex flex-1 text-16 text-black leading-24  font-medium relative`}>
        <View className="flex-1">
          {children}
        </View>
        {rightRenderer && rightRenderer()}
        {arrow && (
          <View className=''>
            <IconArrowThin/>
          </View>
        )}
        
      </View>
    </View>
  );
};
