import { View } from "@tarojs/components";
import style from "./index.module.less";
import { useEffect, useState } from "react";

type Ttype = "primary" | "warn"
interface Props {
  title?: string;
  setShow: (show: boolean) => void;
  show: boolean;
  content: { item: string | JSX.Element; type?: Ttype, onClick?: ()=> void}[];
  header?: JSX.Element | JSX.Element[];
  bottom?: JSX.Element[];
}
export default ({ content, show, setShow }: Props) => {
  const [slideUp, setSlideUp] = useState(false);
  const handleClose = () => {
    setSlideUp(false);
    setTimeout(() => {
      setShow(false);
    }, 100);
  };

  useEffect(() => {
    setTimeout(() => {
      setSlideUp(show);
    }, 100);
  }, [show]);

  const getTypeClassName = (type?: Ttype) => {
    if(type === 'primary'){
      return 'primary-color'
    }
    if(type === 'warn'){
      return 'warn-color'
    }
    return ''
  }

  return (
    <>
      {show && (
        <View className={style.popup}>
          <View className={`${style.container} ${slideUp ? style.show : ""}`}>
            <View className={style.content}>
              {content.map((data, index) => {
                return (
                  <View
                    className={`${style.item}
                    ${getTypeClassName(data.type)}
                    ${
                      index < content.length ? style.bottomBorder : ""
                    }`}
                    onClick={()=> data.onClick && data.onClick()}
                  >
                    {data.item}
                  </View>
                );
              })}
            </View>
            <View className={style.bottomContainer} onClick={handleClose}>
              <View className={style.bottomButton}>取消</View>
            </View>
          </View>
        </View>
      )}
    </>
  );
};
