import { View, Input, ITouchEvent, InputProps } from "@tarojs/components";
import style from "./index.module.less";
import { useState, useRef } from "react";

interface Props {
  placeholder?: string;
  value: string;
  disabled?: boolean;
  prefix?: () => JSX.Element | JSX.Element[] | undefined;
  suffix?: () => JSX.Element | JSX.Element[] | undefined;
  onInput: (value: string) => void;
  confirmType?: keyof InputProps.ConfirmType;
  onConfirm?: (value: string) => void;
  cursorSpacing?: number;
  extraStyle?: Record<string, string>;
  adjustPosition?: boolean
}
let isInbox = false;
const index = ({
  value,
  placeholder = "请输入...",
  cursorSpacing,
  disabled,
  onInput,
  onConfirm,
  confirmType = "done",
  extraStyle,
  prefix,
  suffix,
  adjustPosition,
}: Props) => {
  const [focus, setFocus] = useState(false);
  const inputRef = useRef(null); // 创建一个 ref

  // const handleClear = (e: ITouchEvent) => {
  //   isInbox = true;
  //   e.stopPropagation();
  //   e.preventDefault();
  //   onInput("");
  //   setFocus(true);

  //   //@ts-ignore
  //   inputRef.current && inputRef.current.focus();
  // };
  const handleFocus = () => {
    isInbox = false;
    setFocus(true);
  };
  const handleBlur = () => {
    if (!isInbox) {
      setFocus(false);
    }
  };
  return (
    <View
      className={`${
        focus ? style.inputContainerFocused : style.inputContainer
      } p-12`}
      style={extraStyle}
    >
      <View
        className={style.inputAreaContainer}
        onClick={() => {
          setFocus(true);
        }}
      >
        {prefix && prefix()}
        <Input
          value={value}
          ref={inputRef}
          type="text"
          adjustPosition={adjustPosition}
          onInput={(e: any) => onInput(e.target.value)}
          placeholder={placeholder}
          placeholderStyle="rgba(0,0,0,.05)"
          className={style.textInput}
          onFocus={handleFocus}
          onBlur={handleBlur}
          cursorSpacing={cursorSpacing}
          confirmType={confirmType}
          disabled={disabled}
          onConfirm={(e: any) => {
            onConfirm && onConfirm(e.detail.value);
          }}
        />
        {suffix && suffix()}
      </View>
    </View>
  );
};
export default index;
