import { View, Text, type CommonEvent } from "@tarojs/components"
import IconKeyboard from "@/components/icon/icon-keyboard"
import { useVoiceRecord } from "@/components/voice-recorder";
import { useState } from "react";
import { getChatSession } from "@/store/chat";
import style from './index.module.less'
import { audioRecognition } from "@/service/audio";
interface Props {
  disabled: boolean,
  onIconClick: () => void
  onSend: (msg: string)=> void
  beforeSend: ()=> void
  onError: ()=> void
}
export default ({disabled, onIconClick, onSend, beforeSend, onError}:Props) => {
  const [speechStatus, setSpeechStatus] = useState(0);
  const { start, stop, onStop } = useVoiceRecord();
  const onLongPress = (e?: CommonEvent) => {
    e?.stopPropagation();
    setSpeechStatus(1);
    start();
  };
  const onTouchEnd = () => {
    console.log('touch end')
    setSpeechStatus(0)
    stop()
  };

  const handleTouchStart = (e: CommonEvent) => {
    console.log('touch start')
    // fix 解决pc端长按呼出右键菜单
    // e.preventDefault();
    // fix 解决移动端长按依旧穿透
    // e.stopPropagation();
  };

  onStop(async (res) => {
    console.log("record stop:", res);
    const chatSession = getChatSession()
    beforeSend()
    if (!res || !chatSession) {
      return;
    }
    
    // 以二进制方式读取文件
    const r = await audioRecognition(res.tempFilePath)
    console.log(r);
    if(r.code === 0){
      const msg = r.data?.text ?? ''
      if(!msg.length){
        return;
      }
      onSend(msg)
      return 
    }
    onError()
  });


  const idle = speechStatus === 0;

  return <>
    {/* <TextInputBar onIconClick={handleTextInputBarSwitch}></TextInputBar> */}
    <View className="px-16 py-12">
      <View className={`flex bg-white gap-6 items-center p-16 rounded-10 ${style.speechButton} ${ idle ? '': style.speechButtonActive}`}>
        {idle && <View className="flex items-center" onClick={onIconClick}><IconKeyboard/></View>}
        <View 
          className="flex-1 flex items-center justify-center"
          onLongPress={onLongPress}
          onTouchStart={handleTouchStart}
          onTouchEnd={onTouchEnd}
        >
          <Text className={`text-16 leading-22 font-medium ${idle ? '':'hidden'}`}>按住说话</Text>
        </View>
      </View>
    </View>  
  </>
}