import { useEffect, useState } from "react";
import { View, ScrollView } from "@tarojs/components";
import Taro, { useRouter } from "@tarojs/taro";
import style from './index.module.less'
import ContactCard from "@/components/contact-card/index";
import WemetaTabs from "@/components/wemeta-tabs/index";
import WemetaRadio from "@/components/wemeta-radio/index";
import NavBarNormal from '@/components/nav-bar-normal/index'
import PageCustom from '@/components/page-custom'
import { useCharacterStore } from "@/store/characterStore";
import { usePageStore } from "@/store/pageStore";
import { IContactModel, ICharacter } from "@/types/index";
import { getContactList } from "@/service/contact";
import { APP_NAME_TEXT } from '@/config'


export default function Index() {
  const router = useRouter();
  const { profileId } = router.params;
  const { fetchCharacterList } = useCharacterStore();
  let {setTmpPicked, setPicked} = usePageStore();
  // 未点击确定前按钮前临时选中的卡片
  let tmpPicked = usePageStore((state)=> state.tmpPicked);
  // 已选中的卡片
  let picked = usePageStore((state)=> state.picked);
  const characters = useCharacterStore((state) => state.characters);
  
  // 自己的卡片
  const [myCardList, setMyCardList] = useState<ICharacter[]>([]);
  // 联系人中的卡片
  const [contactList, setContactList] = useState<IContactModel[]>([])
  
  const fetchContactList = async () => {
    const res = await getContactList({ page: 1, pageSize: 50 });
    if (res.code === 0 && res.data) {
      // 将与临时选中的卡片选中状态同步到获取下来的卡片数据上
      const list = res.data.map(item => {
        return {
          ...item,
          checked: tmpPicked.findIndex(pickedItem=> {
            return pickedItem.contactProfileId === item.contactProfileId 
          }) > -1,
        }
      })
      setContactList(list);
    }
  };

  const handleCheck = (character: ICharacter,)=> {
    const newList = myCardList.map((item)=> {
      if(item.profileId === character.profileId){
        return {
          ...item,
          checked: !item.checked
        }  
      }
      return {
        ...item,
      }
    })
    setMyCardList(newList)
    // 如果是取消选中，则临时选中列表中去掉
    if(character.checked){
      setTmpPicked(tmpPicked.filter(item=> item.contactProfileId !== character.profileId))
      return
    }
    // 如果是选中新的，则添加到临时选中的数组中
    const newContact = {
      avatar: character.avatar,
      badges: character.badges,
      company: character.company,
      contactProfileId: character.profileId,
      createdAt: character.createdAt,
      job: character.job,
      name: character.name,
      checked: true
    }
    setTmpPicked([...tmpPicked, newContact])
  }

  const handleContactCheck = (contact: IContactModel)=> {
    const newList = contactList.map((item)=> {
      if(item.contactProfileId === contact.contactProfileId){
        return {
          ...item,
          checked: !item.checked
        }  
      }
      return {
        ...item,
      }
    })
    setContactList(newList)
    
    if(contact.checked){
      setTmpPicked(tmpPicked.filter(item=> item.contactProfileId !== contact.contactProfileId))
      return
    }
    const newContact = {
      ...contact,
      checked: true
    }
    setTmpPicked([...tmpPicked, newContact])
  }


  const handleSave = () => {
    setPicked([...tmpPicked])
    Taro.navigateBack();
  };

  // 渲染自己的卡片列表
  const renderMyCards = () => {
    return (
      <View>
      <ScrollView
      scroll-y
      className={style.listHeight}
      >
        <View className="flex flex-col gap-8 p-20">
          {myCardList.map((item) => {
            return (
              <ContactCard key={item.profileId} data={item} onClick={()=> handleCheck(item)} renderRight={()=> {
                return <WemetaRadio checkbox checked={item.checked}></WemetaRadio>
              }}></ContactCard>
            );
          })}
        </View>
      </ScrollView>
        <View className="px-20" onClick={()=> handleSave()}>
          <View className="button-rounded-big">确认添加</View>  
        </View>
      </View>
    );
  };

  // 渲染联系人列表
  const renderContactCards = () => {
    return (
      <View>
        <ScrollView
      scroll-y
      className={style.listHeight}
      >
      <View className="flex flex-col gap-8 p-20">
        {contactList.map((item) => {
          return (
            <ContactCard key={item.profileId} data={item} onClick={()=> handleContactCheck(item)} renderRight={()=> {
              return <WemetaRadio checkbox checked={item.checked}></WemetaRadio>
            }}></ContactCard>
          );
        })}
      </View>
      </ScrollView>
        <View className="px-20" onClick={()=> handleSave()}>
          <View className="button-rounded-big">确认添加</View>  
        </View>
      </View>
    )
  }
  
  const tabList = [
    {
      key: "1",
      label: "我创建的",
      children: renderMyCards(),
    },
    {
      key: "2",
      label: "我的联系人",
      children: renderContactCards(),
    },
  ];

  


  const initPage =  () => {
    setTmpPicked([...picked])
    fetchCharacterList();
    fetchContactList();
  }
  useEffect(()=> {
    
    setMyCardList(characters.map((item)=> {
      return {
        ...item,
        checked: tmpPicked.findIndex(pickedItem=> pickedItem.contactProfileId === item.profileId) > -1,
      }
    }))
  }, [characters])

  useEffect(() => {
    if (profileId) {
      initPage()
    }
  }, []);

  return (
    <PageCustom>
      <NavBarNormal>{`选择展示的${APP_NAME_TEXT}`}</NavBarNormal>
      <View className="w-full">
        <WemetaTabs
          full
          list={tabList}
          current="1"
          tabStyle="outline"
        ></WemetaTabs>  
      </View>
    </PageCustom>
  );
}
