import { useState } from "react";
import { View, Text, Image } from "@tarojs/components";
import Taro, { useRouter } from "@tarojs/taro";
import PageCustom from "@/components/page-custom/index";
import NavBarNormal from "@/components/nav-bar-normal/index";
import Popup from "@/components/popup/popup";
import style from './index.module.less'
import editorStyle from "../editor.module.less";
import { useCharacterStore } from "@/store/characterStore";
import { useComponentStore } from "@/store/componentStore";
import WemetaInput from "@/components/wemeta-input/index";
import { uploadImage } from "@/utils/http";

export default function Index() {
  const router = useRouter();
  const { id } = router.params;
  const deltaNum = id ? 1 : 2;
  let currentComponent = useComponentStore((state) => state.currentComponent);
  const character = useCharacterStore((state) => state.character);
  const { saveComponent } = useComponentStore();
  const loading = useComponentStore((state) => state.loading);
  const { value } = currentComponent?.data ?? {};
  const [shipingValue, setShipingValue] = useState<{
    accountId: string;
    videoId: string;
    desc: string;
    poster: string;
  }>(value ?? {});

  const [show, setShow] = useState(false);
  const [tipsType, setTipsType] = useState(1);

  const handleSave = async () => {
    if (loading) {
      return;
    }
    if (!shipingValue.accountId || !shipingValue.videoId) {
      return;
    }
    const c = {
      data: {
        value: shipingValue,
        layout: 'mini',
      },
      enabled: currentComponent?.enabled ?? true,
      id: currentComponent?.id,
      name: currentComponent?.name ?? "视频号",
      characterProfileId:
        currentComponent?.characterProfileId ?? character?.profileId,
      type: "channels",
    };
    console.log(c);
    await saveComponent(c);
  };

  const handleNavBack = async () => {
    await handleSave();
  };

  const setValueByKey = (key: string, v: string) => {
    shipingValue[key] = v;
    setShipingValue({
      ...shipingValue,
    });
  };

  const showTips = (type: number) => () => {
    setTipsType(type);
    setShow(true);
  };

  const handleAddPoster = () => {
    Taro.chooseImage({
      count: 1,
      sizeType: ['original', 'compressed'],
      sourceType: ['album', 'camera'],
      async success (chooseImageRes) {
        const tempFilePaths = chooseImageRes.tempFilePaths
        Taro.cropImage({
          src: tempFilePaths[0],
          cropScale: "16:9",
          success: async (cropRes) => {
            const path = cropRes.tempFilePath;
            const res = await uploadImage(path);
            if (res?.code === 0 && res.data) {
              setValueByKey('poster', res.data)
            }
          },
        });
        // tempFilePath可以作为img标签的src属性显示图片
        // const tempFilePaths = response.tempFilePaths
        // Taro.showLoading();
        // const res = await uploadImage(tempFilePaths[0]);
        // Taro.hideLoading();
        // if (res?.code === 0 && res.data) {
        //   setValueByKey('poster', res.data)
        // }
      }
    })
  };

  const renderPoster = (src?: string)=> {
    if(src){
      return (
        <View className="w-full overflow-hidden">
          <Image
            className="w-full"
            mode="widthFix"
            src={src}
          ></Image>
        </View>
      )
    }
    return (
      <>
        <View>
          <Image src='https://cdn.wehome.cn/cmn/png/100/META-H8UKVHWU-KIGP3BIL7M5AYC6XHNUA2-VDZCWI2M-O91.png' className={style.iconAdd}></Image>
        </View>
        <View className="text-gray-45 text-12 leading-20 text-center">建议上传16:9标准尺寸图</View>
      </>
    )
  }

  const renderTips = (type: number) => {
    if (type === 1) {
      return (
        <>
          <View>
            🌟 <Text className="font-medium">小绿提示：</Text>
            <Text>需要登录微信官方视频号助手平台，首页就找到视频号ID。</Text>
          </View>
          <Image
            className="w-full"
            mode="widthFix"
            src="https://cdn.wehome.cn/cmn/png/196/META-H8UK0IWU-9NNPJOLLD1MU95DE0NMA3-8W1EZW2M-2B1.png"
          ></Image>
        </>
      );
    }
    return (
      <>
        <View>
          🌟 <Text className="font-medium">小绿提示：</Text>
          <Text>
            需要登录微信官方视频号助手平台，找到目标视频，点击视频右侧的分享按钮查看。
          </Text>
          <View className="text-orange">视频ID和视频号ID的企业主体一定要相同</View>
        </View>
        <Image
          className="w-full"
          mode="widthFix"
          src="https://cdn.wehome.cn/cmn/png/4/META-H8UKWHWU-6NNPBTA0CSOODDVD47MV3-DFGEZW2M-N81.png"
        ></Image>
      </>
    );
  };

  return (
    <PageCustom>
      <NavBarNormal
        backText="保存"
        navDelta={deltaNum}
        onNavBack={handleNavBack}
      >
        视频号信息
      </NavBarNormal>
      <View className="flex flex-col items-center w-full pt-20">
        <View className={editorStyle.container}>
          <View className={editorStyle.formContainer}>
            <View className={editorStyle.formItem}>
              <View className={editorStyle.formItemLabel}>
                <View className="flex-1">视频号ID</View>
                <View className="text-green" onClick={showTips(1)}>
                  如何获取？
                </View>
              </View>
              <WemetaInput
                value={shipingValue.accountId}
                onInput={(value: string) => setValueByKey("accountId", value)}
                placeholder="请输入视频号ID..."
              />
            </View>
            <View className={editorStyle.formItem}>
              <View className={editorStyle.formItemLabel}>
                <View className="flex-1">视频号视频ID</View>
                <View className="text-green" onClick={showTips(2)}>
                  如何获取？
                </View>
              </View>
              <WemetaInput
                value={shipingValue.videoId}
                onInput={(value: string) => setValueByKey("videoId", value)}
                placeholder="填写视频号ID"
              />
            </View>

            <View className={editorStyle.formItem}>
              <View className={editorStyle.formItemLabel}>
                <View className="flex-1">视频描述</View>
              </View>
              <WemetaInput
                value={shipingValue.desc}
                onInput={(value: string) => setValueByKey("desc", value)}
                placeholder="请输入展示名称..."
              />
            </View>

            <View className={editorStyle.formItem}>
              <View className={editorStyle.formItemLabel}>
                <View className="flex-1">封面图 <Text className="text-gray-45">(选填)</Text></View>
              </View>
              <View className={`${style.coverContainer}`} onClick={handleAddPoster}>
                {renderPoster(shipingValue.poster)}
              </View>
            </View>
            
          </View>
        </View>
      </View>

      <Popup
        title={tipsType === 1 ? "获取视频号ID" : "获取视频号视频ID"}
        show={show}
        setShow={setShow}
      >
        <View className="flex flex-col gap-16 mb-88" onClick={handleAddPoster}>
          <View
            className={`flex flex-col p-12 gap-10 text-14 rounded-20 leading-22 text-gray-65 bg-gray-f8 overflow-hidden`}
          >
            {renderTips(tipsType)}
          </View>
        </View>
      </Popup>
    </PageCustom>
  );
}
