import { forwardRef, useState } from "react";
import { View, Text } from "@tarojs/components";
import editorStyle from "../../../editor.module.less";
import WemetaTextarea from "@/components/wemeta-textarea/index";
import Popup from "@/components/popup/popup/index";
import { useCharacterStore } from "@/store/characterStore";
import ButtonCardAdd from "@/components/button-card-add";
import FoldableList from "./components/foldable-list/index";
interface Props {}
export interface IChatAdvancedComponent {
  saveChild: () => void;
}
export default forwardRef(({}: Props) => {
  const { saveCharacter } = useCharacterStore();
  const currentCharacter = useCharacterStore((state) => state.character);
  const [keyword, setKeyword] = useState("");
  const [question, setQuestion] = useState("");
  const [show, setShow] = useState(false);
  const [questionShow, setQuestionShow] = useState(false);

  const handleAddKeyword = () => {
    if (!keyword.trim().length) {
      return;
    }
    setShow(false);
    if (currentCharacter) {
      console.log("currentCharacter", currentCharacter, keyword);
      const banWords = currentCharacter.banWords ?? [];
      saveCharacter({
        profileId: currentCharacter.profileId,
        banWords: [...banWords, keyword],
      });
    }
  };

  const deleteBanWord = (word: string) => {
    if (currentCharacter) {
      let banWords = currentCharacter.banWords ?? [];
      banWords = banWords.filter((item) => {
        return item !== word;
      });
      saveCharacter({
        profileId: currentCharacter.profileId,
        banWords: [...banWords],
      });
    }
  };
  const deleteQuestion = (qa: string) => {
    if (currentCharacter) {
      let banQuestions = currentCharacter.banQuestions ?? [];
      banQuestions = banQuestions.filter((item) => {
        return item !== qa;
      });
      saveCharacter({
        profileId: currentCharacter.profileId,
        banQuestions: [...banQuestions],
      });
    }
  };

  const handleAddQuestion = () => {
    if (!question.trim().length) {
      return true;
    }
    if (currentCharacter) {
      const banQuestions = currentCharacter.banQuestions ?? [];
      saveCharacter({
        profileId: currentCharacter.profileId,
        banQuestions: [...banQuestions, question],
      });
    }
    setQuestionShow(false);
  };

  const showKeywordPopup = () => {
    setKeyword("");
    setShow(true);
  };

  const showQuestionPopup = () => {
    setQuestion("");
    setQuestionShow(true);
  };

  const renderContent = () => {
    if (currentCharacter) {
      return (
        <View className={editorStyle.formContainer}>
          <View className={editorStyle.formItem}>
            <View className={editorStyle.formItemLabel}>
              禁止 AI 输出的关键词
            </View>
            <ButtonCardAdd text="添加关键词" onClick={showKeywordPopup}>
            {currentCharacter?.banWords && (
                <FoldableList
                  dataList={currentCharacter.banWords}
                  deleteFunc={deleteBanWord}
                />
              )}
            </ButtonCardAdd>
          </View>
          <View className="flex flex-col gap-12">
            <View className={editorStyle.formItem}>
              <View className={editorStyle.formItemLabel}>
                禁止 AI 回答的问题
              </View>
              <ButtonCardAdd text="添加问题" onClick={showQuestionPopup}>
              {currentCharacter.banQuestions && (
                  <FoldableList
                    dataList={currentCharacter.banQuestions}
                    deleteFunc={deleteQuestion}
                  />
                )}
              </ButtonCardAdd>
            </View>
          </View>
        </View>
      );
    }
    return <></>;
  };

  return (
    <View>
      <Popup title="添加禁止 AI 输出的关键词" show={show} setShow={setShow}>
        <View className="flex flex-col gap-16">
          <WemetaTextarea
            value={keyword}
            onInput={(value: any) => setKeyword(value)}
            placeholder="请输入不超过6个字的关键词..."
            cursorSpacing={200}
            maxlength={6}
            bgColor="#F5F6F7"
          />
          <View className="button-rounded-big" onClick={handleAddKeyword}>
            添加
          </View>
          <View className="mt-44 mb-48 text-14 leading-22 font-medium text-gray-65 p-12 rounded-20 bg-gray-f8">
            🌟<Text className="font-medium">小绿提示：</Text>
            好比给AI设定了“红灯停”的规则，让它知道有些话题是敏感或不恰当的，需要避免。
          </View>
        </View>
      </Popup>

      <Popup
        title="添加禁止 AI 回答的问题  (限20字符)"
        show={questionShow}
        setShow={setQuestionShow}
      >
        <View className="flex flex-col gap-16">
          <WemetaTextarea
            value={question}
            onInput={(value: any) => setQuestion(value)}
            placeholder="请输入不超过20个字的问题..."
            cursorSpacing={200}
            maxlength={20}
            bgColor="#F5F6F7"
          />
          <View className="button-rounded-big" onClick={handleAddQuestion}>
            添加
          </View>
          <View className="mt-44 mb-48 pb-28 text-14 leading-22 font-medium text-gray-65 p-12 rounded-20 bg-gray-f8">
            🌟<Text className="font-medium">小绿提示：</Text>
            就像是给AI立了规矩，帮助它知道什么话不能说，什么事不能做
          </View>
        </View>
      </Popup>
      {renderContent()}
    </View>
  );
});
