import { useEffect, forwardRef, useState, useImperativeHandle } from "react";
import { View, Image, Text } from "@tarojs/components";
import CardList from "@/components/list/card-list/index";
import CardListItem from "@/components/list/card-list-item/index";
import editorStyle from "../../../editor.module.less";
import style from "./index.module.less";
import { useCharacterStore } from "@/store/characterStore";
import { ICharacter } from "@/types";
import IconClone from "@/images/icon-renshengkelong-18.png";
import IconVoice from "@/images/icon-voice-18.png";
import WemetaRadio from "@/components/wemeta-radio/index";
import Taro from "@tarojs/taro";
import { useAppStore } from "@/store/appStore";
import { navToVip } from '@/utils/'

interface Props {
  value: ICharacter;
}
export interface IChatBasicComponent {
  save: () => void;
}
export default forwardRef<IChatBasicComponent, Props>(({value}: Props, ref) => {
  const { saveCharacter, fetchVoiceCloneHistory } = useCharacterStore();
  const voiceList = useCharacterStore((state) => state.voiceList);
  const currentCharacter = useCharacterStore((state) => state.character);
  const [mode, setMode] = useState(!!currentCharacter?.voice ? 0 : 1 );
  const isIos = useAppStore((state) => state.isIos);
  const createVoiceNameText = () => {
    const i = voiceList.findIndex((item)=> item.voiceName === currentCharacter?.voice)
    if(i === -1) return ''
    return `克隆声音 0${i+1}`
  }
  const save = async (voice: string) => {
    console.log("save character voice: ", voice);
    
    if (!currentCharacter) {
      return;
    }
    // 保存 voice 至 character
    await saveCharacter({
      profileId: currentCharacter.profileId,
      voice: voice,
    });
  };

  const changeMode = (value: number) => {
    setMode(value);
    if(value === 1){
      save('')
    }else{
      const voiceName = voiceList?.[0]?.voiceName
      if(voiceName){
        save(voiceName)
      }
    }
  };

  const handleSave = () => {
    console.log(value, "save");
    value && saveCharacter({ ...value });
  };
  
  const nav2SystemVoicePage = ()=> {
    console.log({url: '/pages/system-voice/index?profileId='+currentCharacter?.profileId})
    // Taro.navigateTo({url:`/pages/system-voice/index?profileId?=${}`})
    Taro.navigateTo({url: '/pages/system-voice/index?profileId='+currentCharacter?.profileId})
  }

  const nav2Voice = ()=> {
    Taro.navigateTo({url: '/pages/voice/index?profileId='+currentCharacter?.profileId})
  }
  const nav2Member = ()=> {
    if(isIos){
      Taro.showModal({
        content: '根据微信规定，iOS平台暂不提供支付功能。',
        showCancel: false,
      });
      
    } else {
      navToVip()
    }
  }

  useImperativeHandle(ref, () => {
    return {
      save: handleSave,
    };
  });

  useEffect(() => {
    fetchVoiceCloneHistory(value.profileId);
  }, [value.profileId]);

  return (
    <View>
      <View className={editorStyle.formContainer}>
        <View className={editorStyle.formItem}>
          <View className={editorStyle.formItemLabel}>对话音色</View>
          <CardList>
            <CardListItem
              underline
              arrow
              rightRenderer={() => (
                <View className={style.ListItemValue}>{createVoiceNameText()}</View>
              )}
              onClick={nav2Voice}
            >
              <View className="flex items-center gap-8">
                <View className={style.listIconClone}>
                  <Image src={IconClone} className={style.iconImage}></Image>
                </View>
                <View className={style.ListItemText}>克隆声音</View>
              </View>
            </CardListItem>
            <CardListItem
              arrow
              rightRenderer={() => (
                <View className={style.ListItemValue}>{currentCharacter?.defaultSystemVoice}</View>
              )}
              onClick={nav2SystemVoicePage}
            >
              <View className="flex items-center gap-8">
                <View className={style.listIconSystem}>
                  <Image src={IconVoice} className={style.iconImage}></Image>
                </View>
                <View className={style.ListItemText}>系统声音</View>
              </View>
            </CardListItem>
          </CardList>
        </View>

        <View className={editorStyle.formItem}>
          <View className={editorStyle.formItemLabel}>模式选择</View>
          <CardList>
            <CardListItem
              underline
              rightRenderer={() => <WemetaRadio checked={mode === 0} />}
              onClick={() => changeMode(0)}
            >
              <View className="flex flex-col gap-6 pr-36">
                <View className={style.ListItemText}>优先使用克隆声音</View>
                <View className="text-12 leading-22 text-gray-65">
                  当前每天可使用克隆音色对话10分钟，超出限定时长后，自动使用系统音色，{" "}
                  <Text className="primary-color-dark font-medium" onClick={nav2Member}>
                    前往升级
                  </Text>
                </View>
              </View>
            </CardListItem>
            <CardListItem
              rightRenderer={() => <WemetaRadio checked={mode === 1} />}
              onClick={() => changeMode(1)}
            >
              <View className={style.ListItemText}>仅使用系统声音</View>
            </CardListItem>
          </CardList>
        </View>
      </View>
    </View>
  );
});
