import { useState, useEffect, useMemo } from "react";
import { View } from "@tarojs/components";
import Taro, { useRouter } from "@tarojs/taro";
import PageCustom from "@/components/page-custom/index";
import NavBarNormal from "@/components/nav-bar-normal/index";
import ButtonCardAdd from "@/components/button-card-add";
import WemetaTabs from "@/components/wemeta-tabs/index";
import WemetaRadioGroup from "@/components/wemeta-radio-group/index";
import ContactCard from "@/components/contact-card/index";
import editorStyle from "../editor.module.less";
import { useCharacterStore } from "@/store/characterStore";
import { useComponentStore } from "@/store/componentStore";
import { usePageStore } from "@/store/pageStore";
import { IContactModel } from "@/types";
import { batchGet } from "@/service/character";
import { axios, CancelTokenSource } from "taro-axios";
import { APP_NAME_TEXT } from '@/config'

export default function Index() {
  const router = useRouter();
  const { id } = router.params;
  const deltaNum = id ? 1 : 2;
  let currentComponent = useComponentStore((state) => state.currentComponent);
  const character = useCharacterStore((state) => state.character);
  const picked = usePageStore((state) => state.picked);
  const { setPicked, setTmpPicked, clear } = usePageStore();
  const { saveComponent } = useComponentStore();
  const loading = useComponentStore((state) => state.loading);
  const { value, layout } = currentComponent?.data ?? {};
  
  const [radioValue, setRadioValue] = useState(layout ?? "mini");
  const profileId =
    currentComponent?.characterProfileId ?? character?.profileId;
  const radioList = [
    {
      text: "缩略宫格",
      value: "mini",
      checked: false,
    },
    {
      text: "大图平铺",
      value: "full",
      checked: false,
    },
  ];
  const onRadioChange = (value: string) => {
    setRadioValue(value);
    return false;
  };

  const deleteFunc = (item: IContactModel) => {
    const newList = picked.filter(
      (_item) => _item.contactProfileId !== item.contactProfileId
    );
    setTmpPicked([...newList]);
    setPicked(newList);
  };

  const renderContactList = () => {
    if (!picked.length) {
      return (
        <View className="flex flex-col pt-56 items-center">
          <View className="data-empty"></View>
          <View className="text-12 text-gray-45 text-center leading-24 mt-12">
            暂无数据
          </View>
        </View>
      );
    }
    return (
      <View className="flex flex-col gap-8">
        {picked.map((item) => {
          return (
            <ContactCard
              key={item.profileId}
              data={item}
              renderRight={() => {
                return (
                  <View
                    className={`iconfont icon-icon_24_delet icon-24`}
                    onClick={() => deleteFunc(item)}
                  ></View>
                );
              }}
            ></ContactCard>
          );
        })}
      </View>
    );
  };

  const tabList = [
    {
      key: "1",
      label: "内容",
      children: renderContactList(),
    },
    {
      key: "2",
      label: "版式",
      children: (
        <View>
          <WemetaRadioGroup
            radioList={radioList}
            value={radioValue}
            onChange={onRadioChange}
          ></WemetaRadioGroup>
        </View>
      ),
    },
  ];

  const handleSave = async () => {
    const profileIds = [...picked].map((item) => {
      return item.profileId ?? item.contactProfileId;
    });
    if (loading || !profileIds.length) {
      return;
    }
    const c = {
      data: {
        value: profileIds,
        layout: radioValue,
      },
      enabled: currentComponent?.enabled ?? true,
      id: currentComponent?.id,
      name: currentComponent?.name ?? "联系人",
      characterProfileId:
        currentComponent?.characterProfileId ?? character?.profileId,
      type: "contactList",
    };
    console.log(c);
    await saveComponent(c);
  };

  const handleNavBack = async () => {
    await handleSave();
    clear();
  };

  

  const nav2ChooseContact = () => {
    Taro.navigateTo({
      url: `/pages/choose-contact/index?id=${id}&profileId=${profileId}`,
    });
  };
  

  const fetchList = async (cts: CancelTokenSource) => {
    const profileIds = currentComponent?.data?.value as string[] | undefined;
    if (!profileIds) {
      return;
    }
    
    
    const res = await batchGet(profileIds, {
      cancelToken: cts.token
    });
    if (res.code === 0) {
      const picked = res.data.map((item) => {
        return {
          ...item,
          contactProfileId: item.profileId,
        };
      });
      //
      setTmpPicked([...picked]);
      setPicked(picked);
    }
  };
  useEffect(() => {
    let cts = axios.CancelToken.source();
    if (id) {
      fetchList(cts);
    }
    return ()=> {
      return cts.cancel('batchGet request canceled')
    }
  }, [id]);

  return (
    <PageCustom>
      <NavBarNormal
        backText="保存"
        navDelta={deltaNum}
        onNavBack={handleNavBack}
      >
        {`${APP_NAME_TEXT}用户`}
      </NavBarNormal>
      <View className="flex flex-col items-center w-full">
        <View className={editorStyle.container}>
          <ButtonCardAdd
            text={`选择展示的${APP_NAME_TEXT}`}
            onClick={nav2ChooseContact}
          ></ButtonCardAdd>
          <WemetaTabs list={tabList} current="1"></WemetaTabs>
        </View>
      </View>
    </PageCustom>
  );
}
