import { useState } from "react";
import { View, Text, Image } from "@tarojs/components";
import Taro, { useUnload } from '@tarojs/taro'
import PageCustom from "@/components/page-custom/index";
import NavBarNormal from "@/components/nav-bar-normal/index";
import WemetaTabs from "@/components/wemeta-tabs/index";
import editorStyle from "../editor.module.less";
import WemetaRadioGroup from "@/components/wemeta-radio-group/index";
import WemetaTextarea from "@/components/wemeta-textarea/index";
import WemetaInput from "@/components/wemeta-input/index";
import { useCharacterStore } from '@/store/characterStore'
import { useComponentStore } from "@/store/componentStore";
import { SocialMediaType } from "@/consts/socialMedia";

export default function Index() {
  const $instance = Taro.getCurrentInstance()
  const {mediaType, id} = $instance.router?.params ?? {}
  const deltaNum = id ? 1:2;
  let mt = mediaType ?? 'link'
  const defaultLabel = `${SocialMediaType[mt]?.label} 链接`;
  let currentComponent = useComponentStore((state)=>  state.currentComponent);
  const character = useCharacterStore((state)=> state.character);
  const { saveComponent } = useComponentStore();
  const loading = useComponentStore((state)=> state.loading);
  const {link, text, layout} = currentComponent?.data ?? {};
  const [linkValue, setLinkValue] = useState( link ?? '');
  const [linkText, setLinkText] = useState(text?? '');
  const [radioValue, setRadioValue] = useState(layout ?? 'center')
  
  // 是否为视频号, 视频号需要特殊提示
  // 如果后期还有更特殊需求，抽取单独页面
  const isShiping = SocialMediaType[mt]?.value === 'shiping'


  const onRadioChange = (value: string) => {
    setRadioValue(value)
    return false;
  };

  const handleNavBack = async () => {
    await handleSave()
  }

  
  
  const radioList = [
    {
      text: "居中",
      value: "center",
      checked: false,
    },
    {
      text: "左对齐",
      value: "left",
      checked: false,
    },
  ];

  const tabList = [
    {
      key: "1",
      label: "内容",
      children: <View className={`flex flex-col gap-6`}>
      <View className="flex gap-4 items-center">
        <View className={editorStyle.formLabel}>链接描述</View>
        <View className={editorStyle.formLabelRequired}>(选填)</View>
      </View>
      <WemetaInput
        value={linkText}
        onInput={(value: string) => setLinkText(value)}
        placeholder="请输入..."
      />
    </View>,
    },
    {
      key: "2",
      label: "版式",
      children: (
        <WemetaRadioGroup
          radioList={radioList}
          value={radioValue}
          onChange={onRadioChange}
        ></WemetaRadioGroup>
      ),
    },
  ];

  const handleSave = async () => {    
    if(!linkValue.length && !linkText.length){
      return
    }
    if(loading){
      return;
    }
    const c = {
      data: {
        link: linkValue,
        text: linkText,
        layout: radioValue,
      },
      enabled: currentComponent?.enabled ?? true,
      id: currentComponent?.id,
      name: currentComponent?.name ?? defaultLabel,
      characterProfileId: currentComponent?.characterProfileId ?? character?.profileId,
      type: mediaType,
    };

    console.log(c)
    
    await saveComponent(c)
  };


  
  

  return (
    <PageCustom bgColor="global-light-green-bg">
      <NavBarNormal backText="保存" navDelta={deltaNum} onNavBack={handleNavBack}>{defaultLabel}</NavBarNormal>
      <View className="flex flex-col items-center w-full">
        <View className={editorStyle.container}>
          <WemetaTextarea
            value={linkValue}
            onInput={(value: string) => setLinkValue(value)}
            placeholder="填写链接"
          >
          </WemetaTextarea>
          {isShiping && 
            <View className="flex flex-col gap-10 rounded-20 p-12 bg-white mt-48">
              <View className="text-gray-65">
                🌟 <Text className="font-medium">小绿提示：</Text>
                <Text>获取视频号ID的需要登录视频号助手，在首页可以查看自己的视频号ID</Text>
              </View>
              <Image
                className="w-full"
                mode="widthFix"
                src="https://cdn.wehome.cn/cmn/png/196/META-H8UK0IWU-9NNPJOLLD1MU95DE0NMA3-8W1EZW2M-2B1.png"
              ></Image>
            </View>
          }
          <WemetaTabs list={tabList} current="1"></WemetaTabs>
        </View>
      </View>
    </PageCustom>
  );
}
