import { useState } from "react";
import { View,Text,Image } from "@tarojs/components";
import Taro from '@tarojs/taro'
import PageCustom from "@/components/page-custom/index";
import NavBarNormal from "@/components/nav-bar-normal/index";
import WemetaTextarea from "@/components/wemeta-textarea/index";
import WemetaInput from "@/components/wemeta-input/index";

import editorStyle from "../editor.module.less";
import style from './index.module.less'
import WemetaRadioGroup from "@/components/wemeta-radio-group/index";
import { useCharacterStore } from '@/store/characterStore'
import { useComponentStore } from "@/store/componentStore";
import { uploadImage } from "@/utils/http";
export default function Index() {
  const $instance = Taro.getCurrentInstance()
  const id = $instance.router?.params.id
  // 新建时获取 linkType 和 title 
  const linkType = $instance.router?.params.linkType
  const linkTitle = $instance.router?.params.title

  const deltaNum = id ? 1:2;
  let currentComponent = useComponentStore((state)=>  state.currentComponent);
  const character = useCharacterStore((state)=> state.character);
  const { saveComponent } = useComponentStore();
  const loading = useComponentStore((state)=> state.loading);
  const componentData  = currentComponent?.data ?? {};
  const {link, text, layout, poster} = componentData

  const [linkValue, setLinkValue] = useState( link ?? '');
  const [linkText, setLinkText] = useState(text?? '');
  const [linkPoster, setLinkPoster] = useState(poster?? '');
  const [tabIndex, setTabIndex] = useState(0);
  const [radioValue, setRadioValue] = useState(layout  ?? "center")
  const radioList = [
    {
      text: "居中",
      value: "center",
      checked: false,
    },
    {
      text: "左对齐",
      value: "left",
      checked: false,
    },
  ];

  const handleSave = async () => {    
    if(!linkValue.length){
      return
    }
    if(loading){
      return;
    }
    const c = {
      data: {
        link: linkValue,
        text: linkText,
        layout: radioValue,
        poster: linkPoster,
        linkType: componentData.linkType ?? linkType,
        title: componentData.title ?? linkTitle,
      },
      enabled: currentComponent?.enabled ?? true,
      id: currentComponent?.id,
      name: currentComponent?.name ?? "链接",
      characterProfileId: currentComponent?.characterProfileId ?? character?.profileId,
      type: "link",
    };
    
    await saveComponent(c)
  };


  const onRadioChange = (value: string) => {
    setRadioValue(value)
    return false;
  };

  const handleNavBack = async () => {
    await handleSave()
  }
  
  const handleAddPoster = () => {
    Taro.chooseImage({
      count: 1,
      sizeType: ['original', 'compressed'],
      sourceType: ['album', 'camera'],
      async success (chooseImageRes) {
        const tempFilePaths = chooseImageRes.tempFilePaths
        const res = await uploadImage(tempFilePaths[0]);
        if (res?.code === 0 && res.data) {
          setLinkPoster(res.data)
        }
        // Taro.cropImage({
        //   src: tempFilePaths[0],
        //   cropScale: "16:9",
        //   success: async (cropRes) => {
        //     const path = cropRes.tempFilePath;
        //     const res = await uploadImage(path);
        //     if (res?.code === 0 && res.data) {
        //       setLinkPoster(res.data)
        //     }
        //   },
        // });
      }
    })
  };

  const renderPoster = (src?: string)=> {
    if(src){
      return (
        <View className="w-full overflow-hidden">
          <Image
            className={style.cover}
            mode="widthFix"
            src={src}
          ></Image>
        </View>
      )
    }
    return (
      <>
        <View>
          <Image src='https://cdn.wehome.cn/cmn/png/100/META-H8UKVHWU-KIGP3BIL7M5AYC6XHNUA2-VDZCWI2M-O91.png' className={style.iconAdd}></Image>
        </View>
        <View className="text-gray-45 text-12 leading-20 text-center">上传展示图</View>
      </>
    )
  }

  const renderTabContent = () => {
    if (tabIndex == 0) {
      return (
        <View className={editorStyle.formContainer}>
          <View className={editorStyle.formItem}>
            <View className={editorStyle.formItemLabel}>
              <View className={editorStyle.formLabel}>链接描述</View>
              <View className={editorStyle.formLabelRequired}>(选填)</View>
            </View>
            <WemetaInput
                value={linkText}
                onInput={(value: string) => setLinkText(value)}
                placeholder="请输入..."
              />
          </View>
          <View className={editorStyle.formItem}>
            <View className={editorStyle.formItemLabel}>
              <View className="flex-1">封面图 <Text className="text-gray-45">(选填)</Text></View>
            </View>
            <View className={`${style.coverContainer}`} onClick={handleAddPoster}>
              {renderPoster(linkPoster)}
            </View>
          </View>
        </View>
      );
    }
    return (
      <WemetaRadioGroup
        radioList={radioList}
        value={radioValue}
        onChange={onRadioChange}
      ></WemetaRadioGroup>
    );
  };

  return (
    <PageCustom>
      <NavBarNormal backText="保存" navDelta={deltaNum} onNavBack={handleNavBack}>{linkTitle ? linkTitle : '链接'}</NavBarNormal>
      <View className="flex flex-col items-center w-full">
        <View className={editorStyle.container}>
          <WemetaTextarea
            value={linkValue}
            onInput={(value: string) => setLinkValue(value)}
            placeholder="请输入URL..."
          >
          </WemetaTextarea>
          
          <View className="flex items-center gap-12 py-32">
            <View
              className={`button-rounded ${tabIndex === 0 ? "actived" : ""}`}
              onClick={() => setTabIndex(0)}
            >
              内容
            </View>
            <View
              className={`button-rounded ${tabIndex === 1 ? "actived" : ""}`}
              onClick={() => setTabIndex(1)}
            >
              版式
            </View>
          </View>

          {renderTabContent()}
        </View>
      </View>
    </PageCustom>
  );
}
