import { useState } from "react";
import { View } from "@tarojs/components";

import PageCustom from "@/components/page-custom/index";
import NavBarNormal from "@/components/nav-bar-normal/index";
import editorStyle from "../editor.module.less";
import WemetaRadioGroup from "@/components/wemeta-radio-group/index";
import { useComponentStore } from "@/store/componentStore";
import { useCharacterStore } from "@/store/characterStore";
import Taro, { useUnload } from "@tarojs/taro";
import WemetaTextarea from "@/components/wemeta-textarea/index";

export default function Index() {
  const $instance = Taro.getCurrentInstance();
  const id = $instance.router?.params?.id;
  const deltaNum = id ? 1 : 2
  let currentComponent = useComponentStore((state) => state.currentComponent);
  const character = useCharacterStore((state) => state.character);
  const { saveComponent } = useComponentStore();
  const loading = useComponentStore((state) => state.loading);
  const [value, setValue] = useState(currentComponent?.data?.text ?? "");
  const [radioValue, setRadioValue] = useState(currentComponent?.data?.layout ?? 'simple')
  
  const radioList = [
    {
      text: "居中",
      value: "simple",
      checked: false,
    },
    {
      text: "左对齐",
      value: "default",
      checked: false,
    },
  ];

  const onChange = (e: any) => {
    setValue(e);
  };

  const handleSave = async (_newValue?: string) => {
    if (!value.length) {
      return;
    }
    if (loading) {
      return;
    }
    const c = {
      data: {
        text: value,
        layout: radioValue,
      },
      enabled: currentComponent?.enabled ?? true,
      id: currentComponent?.id,
      name: currentComponent?.name ?? "电话",
      characterProfileId:
        currentComponent?.characterProfileId ?? character?.profileId,
      type: "tel",
    };

    await saveComponent(c);
  };

  const onRadioChange = (value: string) => {
    setRadioValue(value)
    return false;
  };

  const handleNavBack = async () => {
    await handleSave()
  }

  

  return (
    <PageCustom>
      <NavBarNormal navDelta={deltaNum} onNavBack={handleNavBack} backText="保存">电话</NavBarNormal>
      <View className="flex flex-col items-center w-full">
        <View className={editorStyle.container}>
          <WemetaTextarea
              value={value}
              onInput={(value: string) => onChange(value)}
              placeholder="请输入电话..."
            />
          <View className="pt-32">
            <WemetaRadioGroup
              radioList={radioList}
              onChange={onRadioChange}
              value={radioValue}
            ></WemetaRadioGroup>
          </View>
        </View>
      </View>
    </PageCustom>
  );
}
