import { useState } from "react";
import { View } from "@tarojs/components";
import PageCustom from "@/components/page-custom/index";
import NavBarNormal from "@/components/nav-bar-normal/index";
import WemetaRadioGroup from "@/components/wemeta-radio-group/index";
import editorStyle from "../editor.module.less";
import { useComponentStore } from "@/store/componentStore";
import { useCharacterStore } from '@/store/characterStore'
import Taro, { useUnload } from "@tarojs/taro";
import WemetaTextarea from "@/components/wemeta-textarea/index";

export default function Index() {
  const $instance = Taro.getCurrentInstance();
  const id = $instance.router?.params?.id;
  const deltaNum = id ? 1 : 2
  let maxIndex = useComponentStore((state)=>  state.maxIndex);
  let currentComponent = useComponentStore((state)=>  state.currentComponent);
  const character = useCharacterStore((state)=> state.character);
  const { saveComponent } = useComponentStore();
  const loading = useComponentStore((state)=> state.loading);
  const [value, setValue] = useState<string>(currentComponent?.data?.text ?? '');

  const [radioValue, setRadioValue] = useState(currentComponent?.data?.layout ?? 'center')
  const radioList = [
    {
      text: "居中",
      value: "center",
      checked: false,
    },
    {
      text: "左对齐",
      value: "left",
      checked: false,
    },
  ];

  const handleSave = async (_newValue?: string) => {
    if(!value.length){
      return
    }
    if(loading){
      return;
    }
    const c = {
      data: {
        text: value,
        layout: radioValue,
      },
      enabled: currentComponent?.enabled ?? true,
      id: currentComponent?.id,
      name: currentComponent?.name ?? "文本内容",
      index: currentComponent?.index ?? (maxIndex+1),
      characterProfileId: currentComponent?.characterProfileId ?? character?.profileId,
      type: "textarea",
    };

    
    await saveComponent(c)
  };

  
  const onChange = (e: any) => {
    setValue(e);
  };

  const onRadioChange = (value: string) => {
    setRadioValue(value)
    return false;
  };

  
  const handleNavBack =  async () => {
    await handleSave()
  }

  

  return (
    <PageCustom bgColor="global-light-green-bg">
      <NavBarNormal backText="保存" navDelta={deltaNum} onNavBack={handleNavBack}>文本内容</NavBarNormal>
      <View className="flex flex-col items-center w-full">
        <View className={editorStyle.container}>
          <View
            className={`${editorStyle.textInputContainer} ${editorStyle.underline}`}
          >
            <WemetaTextarea
              value={value}
              onInput={(value: any) => onChange(value)}
              placeholder="文本内容"
              cursorSpacing={100}
              maxlength={2000}
            />
          </View>
          <View className="pt-32">
            <WemetaRadioGroup
              radioList={radioList}
              onChange={onRadioChange}
              value={radioValue}
            ></WemetaRadioGroup>
          </View>
        </View>
      </View>
    </PageCustom>
  );
}
