import { useState } from "react";
import { View } from "@tarojs/components";

import PageCustom from "@/components/page-custom/index";
import NavBarNormal from "@/components/nav-bar-normal/index";
import editorStyle from "../editor.module.less";
import WemetaRadioGroup from "@/components/wemeta-radio-group/index";
import { useComponentStore } from '@/store/componentStore'
import { useCharacterStore } from '@/store/characterStore'
import WemetaTextarea from "@/components/wemeta-textarea/index";
import Taro, {useRouter, useUnload} from "@tarojs/taro";
export default function Index() {
  const router = useRouter();
  const { id } = router.params;
  const deltaNum = id ? 1 : 2
  let currentComponent = useComponentStore((state)=>  state.currentComponent);
  const character = useCharacterStore((state)=> state.character);
  const loading = useComponentStore((state)=> state.loading);
  const { saveComponent } = useComponentStore();
  const [value, setValue] = useState(currentComponent?.data?.text ?? '');
  const [radioValue, setRadioValue] = useState(currentComponent?.data?.layout ?? 'center')
  const radioList = [
    {
      text: "居中",
      value: "center",
      checked: false,
    },
    {
      text: "左对齐",
      value: "left",
      checked: true,
    },
  ];
  
  const handleSave = async () => {
    if(loading){
      return
    }
    if(value.length <= 0){
      return;
    }
    const c = {
      data: {
        text: value,
        layout: radioValue,
      },
      enabled: currentComponent?.enabled ?? true,
      id: currentComponent?.id,
      name: currentComponent?.name ?? "章节标题",
      index: currentComponent?.index,
      characterProfileId: currentComponent?.characterProfileId ?? character?.profileId,
      type: "title",
    };

    
    await saveComponent(c)
  };

  const onChange = (e: any) => {
    setValue(e);
  };
  

  const onRadioChange = (value: string) => {
    setRadioValue(value)
    return false;
  };

  const handleNavBack = async () => {
    await handleSave()
  }
  
  

  return (
    <PageCustom bgColor="global-light-green-bg">
      <NavBarNormal backText="保存" navDelta={deltaNum} onNavBack={ handleNavBack }>章节标题</NavBarNormal>
      <View className="flex flex-col items-center w-full">
        <View className={editorStyle.container}>
          <View
            className={`${editorStyle.textInputContainer} ${editorStyle.underline}`}
          >
            <WemetaTextarea
              value={value}
              onBlur={(value: string) => onChange(value)}
              onInput={(value: string) => onChange(value)}
              placeholder="章节标题"
              autoFocus
            />
          </View>
          <View className="pt-32">
            <WemetaRadioGroup
              radioList={radioList}
              onChange={onRadioChange}
              value={radioValue}
            ></WemetaRadioGroup>
          </View>
        </View>
      </View>
    </PageCustom>
  );
}
