import { useState } from "react";
import { View } from "@tarojs/components";
import style from "./index.module.less";
import TagCertificated from "@/components/tag-certificated";
import IconSwapBlack from "@/components/icon/icon-swap-black";
import IconChatWhite from "@/components/icon/icon-chat-white";
import IconQRCodeBlack from "@/components/icon/icon-qrcode-black";
import IconSendBlack from "@/components/icon/icon-send-black";
import IconEditBlack from "@/components/icon/icon-edit-black";
import IconMoreBlack from "@/components/icon/icon-more-black";

import IconPhoneGray from "@/components/icon/icon-phone-gray";
import IconMailGray from "@/components/icon/icon-mail-gray";
import IconLocationGray from "@/components/icon/icon-location-gray";
import { useAppStore } from "@/store/appStore";
import AgentSwap from "../agent-swap/index";
import AgentQRCode from "../agent-qrcode/index";
import SharePopup from "@/components/custom-share/share-popup";
import Taro from "@tarojs/taro";
import PopupSheets from "@/components/popup/popup-sheets";

export default () => {
  const headerHeight = useAppStore((state) => state.headerHeight);
  const [showAgentSwap, setShowAgentSwap] = useState(false);
  const [showAgentQRcode, setShowAgentQRcode] = useState(false);
  const [showPopup, setShowPopup] = useState(false);
  const [showShare, setShowShare] = useState(false);

  // 自定义背景样式
  const bgImageStyle = {
    marginTop: -headerHeight,
    // background: `linear-gradient(rgba(242, 244, 245, 0) 0%, rgba(242, 244, 245, .8) 80% , rgba(242, 244, 245,1) 100%), url(${customBgImg})`,
    backgroundImage: `url(https://cdn.wehome.cn/cmn/png/53/META-H8UKWHWU-2JNUAG2BARJF55VHU9QS3-YBQGHDAM-IW.png)`,
  };
  return (
    <View className="relative">
      <View className={style.topBg} style={bgImageStyle}></View>
      <View className={style.topBarContainer}>
        <View className={style.topBar}>
          <View className="px-8 mb-16">
            <View className="flex items-start mb-24">
              <View className="flex flex-col flex-1">
                <View className="flex items-end gap-8">
                  <View className="text-24 font-medium leading-32">张三</View>
                  <View className="text-12 leading-20">销售医师</View>
                </View>
                <View className="flex items-center gap-2">
                  <View className="text-12 leading-20 truncate max-w-[188px]">
                    北京茗视光眼科医院管理有限公司
                  </View>
                  <TagCertificated />
                </View>
              </View>
              <View
                className={style.boxButton}
                onClick={() => {
                  setShowAgentSwap(true);
                }}
              >
                <IconSwapBlack />
              </View>
            </View>
            <View className="flex items-center gap-8">
              <View className="flex-1">
                <View
                  className="button-rounded button-primary"
                  onClick={() => {
                    Taro.navigateTo({
                      url: "/pages/chat/index",
                    });
                  }}
                >
                  <IconChatWhite />
                  和TA聊聊
                </View>
              </View>
              <View
                className={style.boxButton}
                onClick={() => {
                  setShowAgentSwap(true);
                }}
              >
                <IconQRCodeBlack />
              </View>
              <View
                className={style.boxButton}
                onClick={() => {
                  setShowShare(true);
                }}
              >
                <IconSendBlack />
              </View>
              <View
                className={style.boxButton}
                onClick={() => {
                  Taro.navigateTo({ url: "/pages/editor-contact/index" });
                }}
              >
                <IconEditBlack />
              </View>
              <View className={style.boxButton} onClick={()=> {
                setShowPopup(true)
              }}>
                <IconMoreBlack />
              </View>
            </View>
          </View>

          <View className="rounded-12 bg-white p-20">
            <View className="text-14 leading-22 font-medium border-b border-b-gray h-34 mb-22">
              联系方式
            </View>
            <View className="flex flex-col gap-20 text-12 leading-20">
              <View className="flex items-center gap-12">
                <View className={style.icon}>
                  <IconPhoneGray />
                </View>
                <View>137 1234 1234</View>
              </View>
              <View className="flex items-center gap-12">
                <View className={style.icon}>
                  <IconMailGray />
                </View>
                <View>zhangsan@eyeclear.com</View>
              </View>
              <View className="flex items-center gap-12">
                <View className={style.icon}>
                  <IconLocationGray />
                </View>
                <View>浙江省杭州市上城区钱江国际时代广场2幢</View>
              </View>
            </View>
          </View>
        </View>
      </View>

      <AgentSwap show={showAgentSwap} setShow={setShowAgentSwap}></AgentSwap>
      <AgentQRCode show={showAgentQRcode} setShow={setShowAgentQRcode} />
      <SharePopup
        show={showShare}
        setShow={setShowShare}
        character={null}
      ></SharePopup>
      <PopupSheets 
          setShow={setShowPopup} 
          show={showPopup}
          content={[
            {item: <View className="text-12 font-normal text-gray-45">删除后所有数据将被清空，且无法恢复</View>}, 
            {item:'删除', type: 'warn', onClick: ()=> {
              Taro.showModal({
                content: '确认删除该智能体？',
                success: function (res) {
                  if (res.confirm) {
                    console.log('用户点击确定')
                  } else if (res.cancel) {
                    console.log('用户点击取消')
                  }
                  setShowPopup(false);
                }
              })
              
            }},
          ]}
        >
        </PopupSheets>
    </View>
  );
};
