import IconPause from "@/images/svgs/icon_pause.svg";
import IconPlay from "@/images/svgs/icon_play.svg";
import { voiceTryout } from "@/service/audio";
import { useBase64AudioPlayer } from "@/utils/audioBase64";
import { Image, View } from "@tarojs/components";
import { useEffect, useState } from "react";
import { axios } from "taro-axios";
import popupStyle from "./index.module.less";

interface Props {
  voiceName: string;
  showName: string;
  show: boolean;
  onSure: () => void;
  onReclone: () => void;
}

export default ({ voiceName, showName, onSure, show, onReclone }: Props) => {
  const { playAudio, stopAudio, onEnded } = useBase64AudioPlayer();
  const [playing, setPlaying] = useState(false);
  let cancelTokenSource = axios.CancelToken.source();
  const playVoice = async (voice: string) => {
    // 在发起请求前取消之前的请求
    cancelTokenSource.cancel("Previous request canceled");
    stopAudio();
    try {
      // 重新创建一个新的取消令牌源
      cancelTokenSource = axios.CancelToken.source();

      const res = await voiceTryout(voice, {
        cancelToken: cancelTokenSource.token,
      });

      if (res?.data?.audio) {
        playAudio(res.data.audio);
        setPlaying(true);
      }
    } catch (e) {
      setPlaying(false);
    }
  };
  useEffect(() => {
    if (show) {
      console.log("voiceName tryOut >>", voiceName);
      playVoice(voiceName);
    }
    return () => {
      stopAudio();
    };
  }, [show, voiceName]);
  onEnded(() => {
    setPlaying(false);
  });

  return (
    <View className={popupStyle.container}>
      <View className={popupStyle.content}>
        <View className={popupStyle.title}>{showName}</View>
        <View className={popupStyle.desc}>
          克隆数量有限，确认后将占用一个额度
        </View>
        <View
          className={popupStyle.iconBg}
          onClick={() => {
            playVoice(voiceName);
          }}
        >
          <Image
            src={playing ? IconPlay : IconPause}
            className={popupStyle.icon}
          ></Image>
        </View>
        <View className="flex flex-col w-full mt-48">
          <View
            className={popupStyle.actionButton}
            onClick={() => {
              onSure();
            }}
          >
            确认使用
          </View>
          <View
            className={popupStyle.recloneButton}
            onClick={() => {
              onReclone();
            }}
          >
            重新克隆
          </View>
        </View>
      </View>
    </View>
  );
};
