import { create } from 'zustand'
import { getAppConfig } from '@/service/appConfig'
import { TModelAppConfig, TModelVipProduct } from '@/types/index'
import { useUserStore } from './userStore'
import Taro from '@tarojs/taro'
export interface AppState {
  value: number
  headerHeight: number
  topDistance: number
  statusBarHeight: number
  colorPrimary: string
  colorTextPrimary: string
  systemInfo: Taro.getSystemInfoAsync.Result | null
  isIos: boolean,
  appConfig: TModelAppConfig | null
  keyboardHeight: number
  vip: TModelVipProduct | null,
  vipPopupVisible: boolean
  authPhonePopupVisible: boolean
  desktopPopupTips: boolean
  setVipPopupVisible: (showVipPopup: boolean)=> void
  setAuthPhoneVisible: (visible: boolean)=> void
  setSystemInfo: (info: Taro.getSystemInfoAsync.Result)=> void
  setKeyboardHeight: (height: number) => void
  fetchAppConfig: ()=> Promise<TModelAppConfig | null>
  setVip: (vip: TModelVipProduct)=> void
}

export const useAppStore = create<AppState>((set) => ({
  value: 0,
  topDistance: 0, // 内容距离顶部的距离
  headerHeight: 0, // 头部高度
  statusBarHeight: 0, // 头部高度
  colorPrimary: '#CBF706', // 主题色
  colorTextPrimary: '#262626', // 主题色
  systemInfo: null,
  appConfig: null,
  isIos: false,
  keyboardHeight: 0, // 弹出键盘高度
  vip: null,
  vipPopupVisible: false,
  desktopPopupTips: false,
  authPhonePopupVisible: false,
  setVipPopupVisible: (vipPopupVisible: boolean)=> {
    set({vipPopupVisible})
  },
  setAuthPhoneVisible: (visible: boolean)=> {
    set({authPhonePopupVisible: visible})
  },
  setKeyboardHeight: (height: number)=> {
    set({keyboardHeight: height})
  },
  setSystemInfo: (info) => {
    // 状态栏高度 - 6 偏差值为垂直居中对齐胶囊按钮
    const statusBarHeight = (isNaN(info.statusBarHeight!) ? 24 : info.statusBarHeight || 47) - 6;
    const system = info.system.toLowerCase() 
    const isIos = system.includes('ios')
    let desktopPopupTips = false;
    const capsuleInfo = Taro.getMenuButtonBoundingClientRect()
    
    // 导航栏高度 = 胶囊和状态栏之间的留白 * 2 胶囊高度
    let navbarHeight = (capsuleInfo.top - statusBarHeight) * 2 + capsuleInfo.height
    
    // Android 导航栏高度多加 4
    navbarHeight = isIos ? navbarHeight : navbarHeight + 4
    
    // 整个 header 高度
    const headerHeight = statusBarHeight + navbarHeight

    // console.log({ systemInfo: info, statusBarHeight: statusBarHeight, headerHeight, capsuleInfo, navbarHeight})

    // 如果是 Mac 或 windows 电脑平台则不允许使用 并 显示小程序二维码
    if (!system.includes('android') && !system.includes('ios')) {
      desktopPopupTips = true
    }
    // statusBarHeight 离顶部导航栏位置
    set({ systemInfo: info, statusBarHeight, headerHeight, isIos, desktopPopupTips})
    
      
  },
  fetchAppConfig: async ()=> {
    const res = await getAppConfig()
    
    if(res?.code === 0 && res.data){
      set(() => {
        return {
          appConfig: {...res.data},
        }
      })
      return res.data
    }
    return null
  },
  setVip:  (vip: TModelVipProduct)=> {
    set({
      vip,
    })
  }
}))

export const useUserPhone = ()=> {
  return useUserStore((state)=> state.user?.phone)
}


