import Taro from "@tarojs/taro";
import axios from './http'
import { getToken, setToken } from '@/utils/index'

import { authBind } from "@/service/auth";
import { EBindKind } from "@/consts/enum";

let isLogining = false;


const authLoginH5 = async (resolve) => {
	const BrowserID = await require("browser-id");
	const fingerprint = BrowserID()
	console.log("figerprint", fingerprint)
	//发起网络请求
	const result = await axios.get<unknown, { code: number, data: string }>('/v1/auth/browser/oauthLogin', { params: { code: fingerprint, referralCode } })
	if (result?.code === 0) {
		setToken(result.data)
		resolve(true)
		return
	}
	resolve(false)
	return;
}

export const authLogin = (): Promise<boolean> => {
	const launchOptions = Taro.getLaunchOptionsSync()
	// 如果有 referralCode 参数，则说明是通过分享的方式进入小程序，则需要获取 referralCode 参数
	const referralCode = launchOptions.query?.referralCode
	return new Promise(async (resolve, reject) => {
		const token = getToken()
		if (token) {
			resolve(true)
			return;
		}
		if (isLogining) {
			return 
		}
		isLogining = true;
		if (process.env.TARO_ENV == "h5") {
			await authLoginH5(resolve)
			isLogining = false;
			return;
		}

		Taro.login({
			complete(){
				isLogining = false;	
			},
			async success(res) {
				console.log(res);
				if (res.code) {
					//发起网络请求
					const result = await axios.get<unknown, { code: number, data: string }>('/v1/auth/wechat/oauthLogin', { params: { code: res.code, ref: referralCode } })
					if (result?.code === 0) {
						setToken(result.data)
						resolve(true)
					}
				} else {
					console.log('登录失败！' + res.errMsg)
					reject(false)
				}
			}, fail(res) {
				console.log('登录失败！' + res.errMsg)
				reject(false)
			}
		})
	})
}

// 用户未授权
export const showAuthModal = (content: string) => {
	Taro.showModal({
		title: '需要授权',
		content: content,
		showCancel: false,
		confirmText: '去授权',
		success: function (res) {
			if (res.confirm) {
				// 用户点击去授权，跳转到设置页面
				Taro.openSetting({
					success: function (data) {
						console.log(data)
						// if (data.authSetting['scope.writePhotosAlbum']) {
						// 	// 用户重新授权后，可以再次调用相关接口
						// 	// 这里可以再次尝试获取用户信息
						// }
					},
					fail: function (err) {
						console.error('打开设置失败', err);
					}
				});
			}
		}
	});
}

// 权限测试
// 'scope.writePhotosAlbum'
// 'scope.record'
export const checkPermission = async (scope: string):Promise<boolean> => {
	return new Promise((resolve) => {
		Taro.authorize({
			scope: scope,
			success(res) {
				console.log(res)
				resolve(true);
			},
			fail(err) {
				console.warn(err)
				resolve(false);
			}
		});
	});
}

export const bindPhone = async (phone: string) => {
	const res = await authBind(EBindKind.WechatPhone, phone);
	if (res.data) {
		return res.data
	}
	return null
}